.. malaya documentation master file, created by
   sphinx-quickstart on Sat Dec  8 23:44:35 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Malaya's documentation!
======================================

.. include::
   README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   Installation
   Dataset
   Accuracy
   Cache
   Transformer
   Augmentation
   Cluster
   Dependency
   Emotion
   Entities
   Generator
   Language
   Lexicon
   Normalizer
   Num2word
   Pos
   Preprocessing
   Relevancy
   Sentiment
   Similarity
   Spell
   Stack
   Stemmer
   Subjective
   Summarization
   Topic
   Toxic
   Word2num
   Wordvector
   Cluster
   Api
   Contributing
   Crawler
   Translator-malaya
   Reference
